<TS language="es_DO" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>Haga clic con el botón derecho para editar una dirección o etiqueta</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>Crear una nueva dirección</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nuevo</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Copiar la dirección seleccionada al portapapeles del sistema</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Copiar</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Borrar de la lista la dirección seleccionada</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation>Introduzca una dirección o etiqueta que buscar</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Exportar a un archivo los datos de esta pestaña</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Exportar</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Eliminar</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>Escoja la dirección a la que se enviarán monedas</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>Escoja la dirección donde quiere recibir monedas</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>Direcciones de envío</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>Direcciones de recepción</translation>
    </message>
    <message>
        <source>These are your Litecoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>Estas son sus direcciones Litecoin para enviar pagos. Compruebe siempre la cantidad y la dirección de recibo antes de transferir monedas.</translation>
    </message>
    <message>
        <source>These are your Litecoin addresses for receiving payments. It is recommended to use a new receiving address for each transaction.</source>
        <translation>Estas son sus direcciones de Litecoin para recibir pagos. Se recomienda utilizar una nueva dirección de recepción para cada transacción.</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>Exportar la Lista de Direcciones </translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Archivo de columnas separadas por coma (*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>La exportación falló</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>Hubo un error al intentar guardar la lista de direcciones a %1. Por favor trate de nuevo.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Etiqueta</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Dirección</translation>
    </message>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Diálogo de contraseña</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Introducir contraseña</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Nueva contraseña</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Repita la nueva contraseña</translation>
    </message>
    <message>
        <source>Show password</source>
        <translation>Mostrar contraseña</translation>
    </message>
    <message>
        <source>Enter the new passphrase to the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>Introduzca la nueva contraseña para el monedero. &lt;br/&gt;Por favor use una contraseña de &lt;b&gt;diez o más caracteres aleatorios&lt;/b&gt;, u &lt;b&gt;ocho o más palabras&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Cifrar monedero</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Esta operación requiere su contraseña para desbloquear el monedero.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Desbloquear monedero</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>Esta operación requiere su contraseña para descifrar el monedero.</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>Descifrar monedero</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase to the wallet.</source>
        <translation>Introduzca la contraseña anterior y la contraseña nueva para este monedero.</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Confirme cifrado del monedero</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR LITECOINS&lt;/b&gt;!</source>
        <translation>Atención: Si cifra su monedero y pierde la contraseña, perderá ¡&lt;b&gt;TODOS SUS LITECOINS&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>¿Está seguro que desea cifrar su monedero?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Monedero cifrado</translation>
    </message>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Firmar &amp;mensaje...</translation>
    </message>
    <message>
        <source>Synchronizing with network...</source>
        <translation>Sincronizando con la red…</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Vista general</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Mostrar vista general del monedero</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;Transacciones</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Examinar el historial de transacciones</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Salir</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Salir de la aplicación</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Acerca de &amp;Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>Mostrar información acerca de Qt</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Opciones...</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Cifrar monedero…</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet...</source>
        <translation>Copia de &amp;respaldo del monedero...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;Cambiar la contraseña…</translation>
    </message>
    <message>
        <source>Open &amp;URI...</source>
        <translation>Abrir URI...</translation>
    </message>
    <message>
        <source>Reindexing blocks on disk...</source>
        <translation>Reindexando bloques en disco...</translation>
    </message>
    <message>
        <source>Send coins to a Litecoin address</source>
        <translation>Enviar monedas a una dirección Litecoin</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation>Copia de seguridad del monedero en otra ubicación</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Cambiar la contraseña utilizada para el cifrado del monedero</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>Ventana de &amp;depuración</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>Abrir la consola de depuración y diagnóstico</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Verificar mensaje...</translation>
    </message>
    <message>
        <source>Litecoin</source>
        <translation>Litecoin</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Enviar</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Recibir</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>Mo&amp;strar/ocultar</translation>
    </message>
    <message>
        <source>Show or hide the main Window</source>
        <translation>Mostrar u ocultar la ventana principal</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation>Cifrar las claves privadas de su monedero</translation>
    </message>
    <message>
        <source>Sign messages with your Litecoin addresses to prove you own them</source>
        <translation>Firmar mensajes con sus direcciones Litecoin para demostrar la propiedad</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Litecoin addresses</source>
        <translation>Verificar mensajes comprobando que están firmados con direcciones Litecoin concretas</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Archivo</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Configuración</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>A&amp;yuda</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation>Barra de pestañas</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and litecoin: URIs)</source>
        <translation>Solicitar pagos (genera codigo QR y URL's de Litecoin)</translation>
    </message>
    <message>
        <source>Show the list of used sending addresses and labels</source>
        <translation>Mostrar la lista de direcciones de envío y etiquetas</translation>
    </message>
    <message>
        <source>Show the list of used receiving addresses and labels</source>
        <translation>Muestra la lista de direcciones de recepción y etiquetas</translation>
    </message>
    <message>
        <source>Open a litecoin: URI or payment request</source>
        <translation>Abrir un litecoin: URI o petición de pago</translation>
    </message>
    <message>
        <source>&amp;Command-line options</source>
        <translation>&amp;Opciones de linea de comando</translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation>%1 atrás</translation>
    </message>
    <message>
        <source>Last received block was generated %1 ago.</source>
        <translation>El último bloque recibido fue generado hace %1.</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation>Las transacciones posteriores aún no están visibles.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Información</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Actualizado</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Ventana</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Actualizando...</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Transacción enviada</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Transacción entrante</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation>El monedero está &lt;b&gt;cifrado&lt;/b&gt; y actualmente &lt;b&gt;desbloqueado&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>El monedero está &lt;b&gt;cifrado&lt;/b&gt; y actualmente &lt;b&gt;bloqueado&lt;/b&gt;</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Cantidad:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Bytes:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Cuantía:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Tasa:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Después de tasas:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Cambio:</translation>
    </message>
    <message>
        <source>(un)select all</source>
        <translation>(des)selecciona todos</translation>
    </message>
    <message>
        <source>Tree mode</source>
        <translation>Modo arbol</translation>
    </message>
    <message>
        <source>List mode</source>
        <translation>Modo lista</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Cantidad</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Fecha</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Confirmaciones</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Confirmado</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Editar Dirección</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Etiqueta</translation>
    </message>
    <message>
        <source>The label associated with this address list entry</source>
        <translation>La etiqueta asociada con esta entrada de la lista de direcciones</translation>
    </message>
    <message>
        <source>The address associated with this address list entry. This can only be modified for sending addresses.</source>
        <translation>La dirección asociada con esta entrada de la lista de direcciones. Solo puede ser modificada para direcciones de envío.</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Dirección</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>A new data directory will be created.</source>
        <translation>Se creará un nuevo directorio de datos.</translation>
    </message>
    <message>
        <source>name</source>
        <translation>nombre</translation>
    </message>
    <message>
        <source>Directory already exists. Add %1 if you intend to create a new directory here.</source>
        <translation>El directorio ya existe. Añada %1 si pretende crear aquí un directorio nuevo.</translation>
    </message>
    <message>
        <source>Path already exists, and is not a directory.</source>
        <translation>La ruta ya existe y no es un directorio.</translation>
    </message>
    <message>
        <source>Cannot create data directory here.</source>
        <translation>No se puede crear un directorio de datos aquí.</translation>
    </message>
</context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation>versión</translation>
    </message>
    <message>
        <source>Command-line options</source>
        <translation>Opciones de la línea de órdenes</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message>
        <source>Welcome</source>
        <translation>Bienvenido</translation>
    </message>
    <message>
        <source>Use the default data directory</source>
        <translation>Utilizar el directorio de datos predeterminado</translation>
    </message>
    <message>
        <source>Use a custom data directory:</source>
        <translation>Utilice un directorio de datos personalizado:</translation>
    </message>
    <message>
        <source>Litecoin</source>
        <translation>Litecoin</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Form</source>
        <translation>Desde</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Hora del último bloque</translation>
    </message>
    </context>
<context>
    <name>OpenURIDialog</name>
    <message>
        <source>Open URI</source>
        <translation>Abrir URI...</translation>
    </message>
    <message>
        <source>Open payment request from URI or file</source>
        <translation>El pago requiere una URI o archivo</translation>
    </message>
    <message>
        <source>URI:</source>
        <translation>URI:</translation>
    </message>
    <message>
        <source>Select payment request file</source>
        <translation>Seleccione archivo de sulicitud de pago</translation>
    </message>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;Principal</translation>
    </message>
    <message>
        <source>IP address of the proxy (e.g. IPv4: 127.0.0.1 / IPv6: ::1)</source>
        <translation>Dirección IP del proxy (ej. IPv4: 127.0.0.1 / IPv6: ::1)</translation>
    </message>
    <message>
        <source>Reset all client options to default.</source>
        <translation>Restablecer todas las opciones del cliente a las predeterminadas.</translation>
    </message>
    <message>
        <source>&amp;Reset Options</source>
        <translation>&amp;Restablecer opciones</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Red</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation>Monedero</translation>
    </message>
    <message>
        <source>Expert</source>
        <translation>Experto</translation>
    </message>
    <message>
        <source>Automatically open the Litecoin client port on the router. This only works when your router supports UPnP and it is enabled.</source>
        <translation>Abrir automáticamente el puerto del cliente Litecoin en el router. Esta opción solo funciona si el router admite UPnP y está activado.</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>Mapear el puerto usando &amp;UPnP</translation>
    </message>
    <message>
        <source>Proxy &amp;IP:</source>
        <translation>Dirección &amp;IP del proxy:</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>&amp;Puerto:</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>Puerto del servidor proxy (ej. 9050)</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Ventana</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>Minimizar la ventana a la bandeja de iconos del sistema.</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>&amp;Minimizar a la bandeja en vez de a la barra de tareas</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>M&amp;inimizar al cerrar</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Interfaz</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>I&amp;dioma de la interfaz de usuario</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>Mostrar las cantidades en la &amp;unidad:</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>Elegir la subdivisión predeterminada para mostrar cantidades en la interfaz y cuando se envían monedas.</translation>
    </message>
    <message>
        <source>Whether to show coin control features or not.</source>
        <translation>Mostrar o no características de control de moneda</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Aceptar</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>default</source>
        <translation>predeterminado</translation>
    </message>
    <message>
        <source>none</source>
        <translation>ninguno</translation>
    </message>
    <message>
        <source>Confirm options reset</source>
        <translation>Confirme el restablecimiento de las opciones</translation>
    </message>
    <message>
        <source>Client restart required to activate changes.</source>
        <translation>Reinicio del cliente para activar cambios.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>This change would require a client restart.</source>
        <translation>Este cambio requiere reinicio por parte del cliente.</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>La dirección proxy indicada es inválida.</translation>
    </message>
</context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Desde</translation>
    </message>
    <message>
        <source>The displayed information may be out of date. Your wallet automatically synchronizes with the Litecoin network after a connection is established, but this process has not completed yet.</source>
        <translation>La información mostrada puede estar desactualizada. Su monedero se sincroniza automáticamente con la red Litecoin después de que se haya establecido una conexión, pero este proceso aún no se ha completado.</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation>Su balance actual gastable</translation>
    </message>
    <message>
        <source>Total of transactions that have yet to be confirmed, and do not yet count toward the spendable balance</source>
        <translation>Total de transacciones que deben ser confirmadas, y que no cuentan con el balance gastable necesario</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>No disponible:</translation>
    </message>
    <message>
        <source>Mined balance that has not yet matured</source>
        <translation>Saldo recién minado que aún no está disponible.</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>Total:</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation>Su balance actual total</translation>
    </message>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>Cantidad</translation>
    </message>
    <message>
        <source>%1 h</source>
        <translation>%1 h</translation>
    </message>
    <message>
        <source>%1 m</source>
        <translation>%1 m</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/D</translation>
    </message>
    <message>
        <source>%1 B</source>
        <translation>%1 B</translation>
    </message>
    <message>
        <source>%1 KB</source>
        <translation>%1 KB</translation>
    </message>
    <message>
        <source>%1 MB</source>
        <translation>%1 MB</translation>
    </message>
    <message>
        <source>%1 GB</source>
        <translation>%1 GB</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>desconocido</translation>
    </message>
</context>
<context>
    <name>QObject::QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation>N/D</translation>
    </message>
    <message>
        <source>Client version</source>
        <translation>Versión del cliente</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>Información</translation>
    </message>
    <message>
        <source>Debug window</source>
        <translation>Ventana de depuración</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>Hora de inicio</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Red</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>Número de conexiones</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>Cadena de bloques</translation>
    </message>
    <message>
        <source>Current number of blocks</source>
        <translation>Número actual de bloques</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Hora del último bloque</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Abrir</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>&amp;Consola</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation>&amp;Tráfico de Red</translation>
    </message>
    <message>
        <source>Totals</source>
        <translation>Total:</translation>
    </message>
    <message>
        <source>In:</source>
        <translation>Dentro:</translation>
    </message>
    <message>
        <source>Out:</source>
        <translation>Fuera:</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation>Archivo de registro de depuración</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>Borrar consola</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Amount:</source>
        <translation>Cantidad</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Etiqueta:</translation>
    </message>
    <message>
        <source>&amp;Message:</source>
        <translation>Mensaje:</translation>
    </message>
    <message>
        <source>Clear all fields of the form.</source>
        <translation>Limpiar todos los campos del formulario</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Limpiar</translation>
    </message>
    <message>
        <source>&amp;Request payment</source>
        <translation>&amp;Solicitar pago</translation>
    </message>
    <message>
        <source>Show the selected request (does the same as double clicking an entry)</source>
        <translation>Muestra la petición seleccionada (También doble clic)</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>Mostrar</translation>
    </message>
    <message>
        <source>Remove the selected entries from the list</source>
        <translation>Borrar de la lista las direcciónes actualmente seleccionadas</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Eliminar</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>QR Code</source>
        <translation>Código QR</translation>
    </message>
    <message>
        <source>Copy &amp;URI</source>
        <translation>Copiar &amp;URI</translation>
    </message>
    <message>
        <source>Copy &amp;Address</source>
        <translation>Copiar &amp;Dirección</translation>
    </message>
    <message>
        <source>&amp;Save Image...</source>
        <translation>Guardar Imagen...</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Dirección</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etiqueta</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Monedero</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Label</source>
        <translation>Etiqueta</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Enviar monedas</translation>
    </message>
    <message>
        <source>Coin Control Features</source>
        <translation>Características de control de la moneda</translation>
    </message>
    <message>
        <source>Inputs...</source>
        <translation>Entradas...</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation>Seleccionado automaticamente</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Fondos insuficientes!</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Cantidad:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Bytes:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Cuantía:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Tasa:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Después de tasas:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Cambio:</translation>
    </message>
    <message>
        <source>If this is activated, but the change address is empty or invalid, change will be sent to a newly generated address.</source>
        <translation>Al activarse, si la dirección esta vacía o es inválida, las monedas serán enviadas a una nueva dirección generada.</translation>
    </message>
    <message>
        <source>Custom change address</source>
        <translation>Dirección propia</translation>
    </message>
    <message>
        <source>Transaction Fee:</source>
        <translation>Comisión de transacción:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Enviar a múltiples destinatarios de una vez</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>Añadir &amp;destinatario</translation>
    </message>
    <message>
        <source>Clear all fields of the form.</source>
        <translation>Limpiar todos los campos del formulario</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Limpiar &amp;todo</translation>
    </message>
    <message>
        <source>Balance:</source>
        <translation>Saldo:</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Confirmar el envío</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>&amp;Enviar</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Comisión de transacción</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>Ca&amp;ntidad:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>&amp;Pagar a:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Etiqueta:</translation>
    </message>
    <message>
        <source>Choose previously used address</source>
        <translation>Escoger dirección previamente usada</translation>
    </message>
    <message>
        <source>This is a normal payment.</source>
        <translation>Esto es un pago ordinario.</translation>
    </message>
    <message>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Pegar dirección desde portapapeles</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt+P</translation>
    </message>
    <message>
        <source>Remove this entry</source>
        <translation>Eliminar esta transacción</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Mensaje:</translation>
    </message>
    <message>
        <source>Enter a label for this address to add it to the list of used addresses</source>
        <translation>Introduce una etiqueta para esta dirección para añadirla a la lista de direcciones utilizadas</translation>
    </message>
    <message>
        <source>Pay To:</source>
        <translation>Paga a:</translation>
    </message>
    <message>
        <source>Memo:</source>
        <translation>Memo:</translation>
    </message>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation>Firmas - Firmar / verificar un mensaje</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation>&amp;Firmar mensaje</translation>
    </message>
    <message>
        <source>Choose previously used address</source>
        <translation>Escoger dirección previamente usada</translation>
    </message>
    <message>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Pegar dirección desde portapapeles</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt+P</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>Introduzca el mensaje que desea firmar aquí</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation>Firma</translation>
    </message>
    <message>
        <source>Copy the current signature to the system clipboard</source>
        <translation>Copiar la firma actual al portapapeles del sistema</translation>
    </message>
    <message>
        <source>Sign the message to prove you own this Litecoin address</source>
        <translation>Firmar el mensaje para demostrar que se posee esta dirección Litecoin</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Firmar &amp;mensaje</translation>
    </message>
    <message>
        <source>Reset all sign message fields</source>
        <translation>Limpiar todos los campos de la firma de mensaje</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Limpiar &amp;todo</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Verificar mensaje</translation>
    </message>
    <message>
        <source>Verify the message to ensure it was signed with the specified Litecoin address</source>
        <translation>Verificar el mensaje para comprobar que fue firmado con la dirección Litecoin indicada</translation>
    </message>
    <message>
        <source>Verify &amp;Message</source>
        <translation>Verificar &amp;mensaje</translation>
    </message>
    <message>
        <source>Reset all verify message fields</source>
        <translation>Limpiar todos los campos de la verificación de mensaje</translation>
    </message>
    </context>
<context>
    <name>SplashScreen</name>
    <message>
        <source>[testnet]</source>
        <translation>[testnet]</translation>
    </message>
</context>
<context>
    <name>TrafficGraphWidget</name>
    <message>
        <source>KB/s</source>
        <translation>KB/s</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    </context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Esta ventana muestra información detallada sobre la transacción</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Label</source>
        <translation>Etiqueta</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Archivo de columnas separadas por coma (*.csv)</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etiqueta</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Dirección</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>La exportación falló</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Litecoin Core</source>
        <translation>Núcleo de Litecoin</translation>
    </message>
    <message>
        <source>Corrupted block database detected</source>
        <translation>Corrupción de base de datos de bloques detectada.</translation>
    </message>
    <message>
        <source>Do you want to rebuild the block database now?</source>
        <translation>¿Quieres reconstruir la base de datos de bloques ahora?</translation>
    </message>
    <message>
        <source>Error initializing block database</source>
        <translation>Error al inicializar la base de datos de bloques</translation>
    </message>
    <message>
        <source>Error initializing wallet database environment %s!</source>
        <translation>Error al inicializar el entorno de la base de datos del monedero  %s</translation>
    </message>
    <message>
        <source>Error loading block database</source>
        <translation>Error cargando base de datos de bloques</translation>
    </message>
    <message>
        <source>Error opening block database</source>
        <translation>Error al abrir base de datos de bloques.</translation>
    </message>
    <message>
        <source>Error: Disk space is low!</source>
        <translation>Error: ¡Espacio en disco bajo!</translation>
    </message>
    <message>
        <source>Failed to listen on any port. Use -listen=0 if you want this.</source>
        <translation>Ha fallado la escucha en todos los puertos. Use -listen=0 si desea esto.</translation>
    </message>
    <message>
        <source>Incorrect or no genesis block found. Wrong datadir for network?</source>
        <translation>Incorrecto o bloque de génesis no encontrado. Datadir equivocada para la red?</translation>
    </message>
    <message>
        <source>Not enough file descriptors available.</source>
        <translation>No hay suficientes descriptores de archivo disponibles. </translation>
    </message>
    <message>
        <source>Verifying blocks...</source>
        <translation>Verificando bloques...</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Información</translation>
    </message>
    <message>
        <source>Signing transaction failed</source>
        <translation>Transacción falló</translation>
    </message>
    <message>
        <source>Transaction amount too small</source>
        <translation>Monto de la transacción muy pequeño</translation>
    </message>
    <message>
        <source>Transaction too large</source>
        <translation>Transacción demasiado grande</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation>La red especificada en -onlynet '%s' es desconocida</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Fondos insuficientes</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Cargando el índice de bloques...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Cargando monedero...</translation>
    </message>
    <message>
        <source>Cannot downgrade wallet</source>
        <translation>No se puede rebajar el monedero</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Reexplorando...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Generado pero no aceptado</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
</context>
</TS>